@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -8,26 +9,29 @@
     >>> os.chdir(datadir)
 
 """
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
+from builtins import range
 
-from nipype.interfaces.base import (
-    BaseInterface, BaseInterfaceInputSpec, traits,
-    File, TraitedSpec, Directory, isdefined)
 import os
 import os.path as op
+import shutil
+import warnings
+
 import numpy as np
 import nibabel as nb
 import networkx as nx
-import shutil
-from nipype.utils.misc import package_check
-import warnings
 
 from ... import logging
+from ...utils.misc import package_check
+from ..base import (BaseInterface, BaseInterfaceInputSpec, traits, File,
+                    TraitedSpec, Directory, isdefined)
 iflogger = logging.getLogger('interface')
 
 have_cmp = True
 try:
     package_check('cmp')
-except Exception, e:
+except Exception as e:
     have_cmp = False
 else:
     import cmp
@@ -43,8 +47,8 @@ def create_annot_label(subject_id, subjects_dir, fs_dir, parcellation_name):
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
     for hemi in ['lh', 'rh']:
-        spath = cmp_config._get_lausanne_parcellation(
-            'Lausanne2008')[parcellation_name]['fs_label_subdir_name'] % hemi
+        spath = cmp_config._get_lausanne_parcellation('Lausanne2008')[
+            parcellation_name]['fs_label_subdir_name'] % hemi
         paths.append(spath)
     for p in paths:
         try:
@@ -126,21 +130,24 @@ def create_annot_label(subject_id, subjects_dir, fs_dir, parcellation_name):
     log = cmp_config.get_logger()
 
     for out in comp:
-        mris_cmd = 'mris_ca_label %s %s "%s/surf/%s.sphere.reg" "%s" "%s" ' % (subject_id, out[0],
-                                                                               op.join(subjects_dir, subject_id), out[0], cmp_config.get_lausanne_atlas(out[1]), op.join(fs_label_dir, out[2]))
+        mris_cmd = 'mris_ca_label %s %s "%s/surf/%s.sphere.reg" "%s" "%s" ' % (
+            subject_id, out[0], op.join(subjects_dir, subject_id), out[0],
+            cmp_config.get_lausanne_atlas(out[1]),
+            op.join(fs_label_dir, out[2]))
         runCmd(mris_cmd, log)
         iflogger.info('-----------')
 
         annot = '--annotation "%s"' % out[4]
 
-        mri_an_cmd = 'mri_annotation2label --subject %s --hemi %s --outdir "%s" %s' % (subject_id, out[0], op.join(output_dir, out[3]), annot)
+        mri_an_cmd = 'mri_annotation2label --subject %s --hemi %s --outdir "%s" %s' % (
+            subject_id, out[0], op.join(output_dir, out[3]), annot)
         iflogger.info(mri_an_cmd)
         runCmd(mri_an_cmd, log)
         iflogger.info('-----------')
         iflogger.info(os.environ['SUBJECTS_DIR'])
-    # extract cc and unknown to add to tractography mask, we do not want this as a region of interest
-    # in FS 5.0, unknown and corpuscallosum are not available for the 35 scale (why?),
-    # but for the other scales only, take the ones from _60
+        # extract cc and unknown to add to tractography mask, we do not want this as a region of interest
+        # in FS 5.0, unknown and corpuscallosum are not available for the 35 scale (why?),
+        # but for the other scales only, take the ones from _60
         rhun = op.join(output_dir, 'rh.unknown.label')
         lhun = op.join(output_dir, 'lh.unknown.label')
         rhco = op.join(output_dir, 'rh.corpuscallosum.label')
@@ -149,15 +156,21 @@ def create_annot_label(subject_id, subjects_dir, fs_dir, parcellation_name):
         op.join(output_dir, 'regenerated_rh_60', 'rh.unknown.label'), rhun)
     shutil.copy(
         op.join(output_dir, 'regenerated_lh_60', 'lh.unknown.label'), lhun)
-    shutil.copy(op.join(
-        output_dir, 'regenerated_rh_60', 'rh.corpuscallosum.label'), rhco)
-    shutil.copy(op.join(
-        output_dir, 'regenerated_lh_60', 'lh.corpuscallosum.label'), lhco)
+    shutil.copy(
+        op.join(output_dir, 'regenerated_rh_60', 'rh.corpuscallosum.label'),
+        rhco)
+    shutil.copy(
+        op.join(output_dir, 'regenerated_lh_60', 'lh.corpuscallosum.label'),
+        lhco)
 
-    mri_cmd = """mri_label2vol --label "%s" --label "%s" --label "%s" --label "%s" --temp "%s" --o  "%s" --identity """ % (rhun, lhun, rhco, lhco, op.join(op.join(subjects_dir, subject_id), 'mri', 'orig.mgz'), op.join(fs_label_dir, 'cc_unknown.nii.gz') )
+    mri_cmd = """mri_label2vol --label "%s" --label "%s" --label "%s" --label "%s" --temp "%s" --o  "%s" --identity """ % (
+        rhun, lhun, rhco, lhco,
+        op.join(op.join(subjects_dir, subject_id), 'mri', 'orig.mgz'),
+        op.join(fs_label_dir, 'cc_unknown.nii.gz'))
     runCmd(mri_cmd, log)
     runCmd('mris_volmask %s' % subject_id, log)
-    mri_cmd = 'mri_convert -i "%s/mri/ribbon.mgz" -o "%s/mri/ribbon.nii.gz"' % (op.join(subjects_dir, subject_id), op.join(subjects_dir, subject_id))
+    mri_cmd = 'mri_convert -i "%s/mri/ribbon.mgz" -o "%s/mri/ribbon.nii.gz"' % (
+        op.join(subjects_dir, subject_id), op.join(subjects_dir, subject_id))
     runCmd(mri_cmd, log)
     mri_cmd = 'mri_convert -i "%s/mri/aseg.mgz" -o "%s/mri/aseg.nii.gz"' % (
         op.join(subjects_dir, subject_id), op.join(subjects_dir, subject_id))
@@ -175,8 +188,8 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
     log = cmp_config.get_logger()
-    parval = cmp_config._get_lausanne_parcellation(
-        'Lausanne2008')[parcellation_name]
+    parval = cmp_config._get_lausanne_parcellation('Lausanne2008')[
+        parcellation_name]
     pgpath = parval['node_information_graphml']
     aseg = nb.load(op.join(fs_dir, 'mri', 'aseg.nii.gz'))
     asegd = aseg.get_data()
@@ -201,8 +214,9 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
                 dist[x, y, z] = np.sqrt(np.sum(np.multiply(distxyz, distxyz)))
 
     iflogger.info("Working on parcellation: ")
-    iflogger.info(cmp_config._get_lausanne_parcellation(
-        'Lausanne2008')[parcellation_name])
+    iflogger.info(
+        cmp_config._get_lausanne_parcellation('Lausanne2008')[
+            parcellation_name])
     iflogger.info("========================")
     pg = nx.read_graphml(pgpath)
     # each node represents a brain region
@@ -210,7 +224,7 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
     rois = np.zeros((256, 256, 256), dtype=np.int16)
 
     count = 0
-    for brk, brv in pg.nodes_iter(data=True):
+    for brk, brv in pg.nodes(data=True):
         count = count + 1
         iflogger.info(brv)
         iflogger.info(brk)
@@ -220,25 +234,25 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
             hemi = 'rh'
         if brv['dn_region'] == 'subcortical':
             iflogger.info(brv)
-            iflogger.info("---------------------")
-            iflogger.info("Work on brain region: %s" % (brv['dn_region']))
-            iflogger.info("Freesurfer Name: %s" % brv['dn_fsname'])
-            iflogger.info("Region %s of %s " % (count, pg.number_of_nodes()))
-            iflogger.info("---------------------")
+            iflogger.info('---------------------')
+            iflogger.info('Work on brain region: %s', brv['dn_region'])
+            iflogger.info('Freesurfer Name: %s', brv['dn_fsname'])
+            iflogger.info('Region %s of %s', count, pg.number_of_nodes())
+            iflogger.info('---------------------')
             # if it is subcortical, retrieve roi from aseg
             idx = np.where(asegd == int(brv['dn_fs_aseg_val']))
             rois[idx] = int(brv['dn_correspondence_id'])
 
         elif brv['dn_region'] == 'cortical':
             iflogger.info(brv)
-            iflogger.info("---------------------")
-            iflogger.info("Work on brain region: %s" % (brv['dn_region']))
-            iflogger.info("Freesurfer Name: %s" % brv['dn_fsname'])
-            iflogger.info("Region %s of %s " % (count, pg.number_of_nodes()))
-            iflogger.info("---------------------")
+            iflogger.info('---------------------')
+            iflogger.info('Work on brain region: %s', brv['dn_region'])
+            iflogger.info('Freesurfer Name: %s', brv['dn_fsname'])
+            iflogger.info('Region %s of %s', count, pg.number_of_nodes())
+            iflogger.info('---------------------')
 
-            labelpath = op.join(
-                output_dir, parval['fs_label_subdir_name'] % hemi)
+            labelpath = op.join(output_dir,
+                                parval['fs_label_subdir_name'] % hemi)
             # construct .label file name
 
             fname = '%s.%s.label' % (hemi, brv['dn_fsname'])
@@ -246,8 +260,9 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
             # execute fs mri_label2vol to generate volume roi from the label file
             # store it in temporary file to be overwritten for each region
 
-            mri_cmd = 'mri_label2vol --label "%s" --temp "%s" --o "%s" --identity' % (op.join(labelpath, fname),
-                                                                                      op.join(fs_dir, 'mri', 'orig.mgz'), op.join(output_dir, 'tmp.nii.gz'))
+            mri_cmd = 'mri_label2vol --label "%s" --temp "%s" --o "%s" --identity' % (
+                op.join(labelpath, fname), op.join(fs_dir, 'mri', 'orig.mgz'),
+                op.join(output_dir, 'tmp.nii.gz'))
             runCmd(mri_cmd, log)
 
             tmp = nb.load(op.join(output_dir, 'tmp.nii.gz'))
@@ -261,17 +276,17 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
         out_roi = op.abspath('ROI_%s.nii.gz' % parcellation_name)
 
         # update the header
-        hdr = aseg.get_header()
+        hdr = aseg.header
         hdr2 = hdr.copy()
         hdr2.set_data_dtype(np.uint16)
 
         log.info("Save output image to %s" % out_roi)
-        img = nb.Nifti1Image(rois, aseg.get_affine(), hdr2)
+        img = nb.Nifti1Image(rois, aseg.affine, hdr2)
         nb.save(img, out_roi)
 
     iflogger.info("[ DONE ]")
     # dilate cortical regions
-    if (dilation == True):
+    if dilation is True:
         iflogger.info("Dilating cortical regions...")
         # loop throughout all the voxels belonging to the aseg GM volume
         for j in range(xx.size):
@@ -291,8 +306,8 @@ def create_roi(subject_id, subjects_dir, fs_dir, parcellation_name, dilation):
 
         # store volume eg in ROIv_scale33.nii.gz
         out_roi = op.abspath('ROIv_%s.nii.gz' % parcellation_name)
-        iflogger.info("Save output image to %s" % out_roi)
-        img = nb.Nifti1Image(rois, aseg.get_affine(), hdr2)
+        iflogger.info('Save output image to %s', out_roi)
+        img = nb.Nifti1Image(rois, aseg.affine, hdr2)
         nb.save(img, out_roi)
 
         iflogger.info("[ DONE ]")
@@ -303,8 +318,8 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
     fs_dir = op.join(subjects_dir, subject_id)
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
-    pgpath = cmp_config._get_lausanne_parcellation(
-        'Lausanne2008')[parcellation_name]['node_information_graphml']
+    pgpath = cmp_config._get_lausanne_parcellation('Lausanne2008')[
+        parcellation_name]['node_information_graphml']
     # load ribbon as basis for white matter mask
     fsmask = nb.load(op.join(fs_dir, 'mri', 'ribbon.nii.gz'))
     fsmaskd = fsmask.get_data()
@@ -345,35 +360,21 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
 
     # lateral ventricles, thalamus proper and caudate
     # the latter two removed for better erosion, but put back afterwards
-    idx = np.where((asegd == 4) |
-                  (asegd == 43) |
-                  (asegd == 11) |
-                  (asegd == 50) |
-                  (asegd == 31) |
-                  (asegd == 63) |
-                  (asegd == 10) |
-                  (asegd == 49))
+    idx = np.where((asegd == 4) | (asegd == 43) | (asegd == 11) | (asegd == 50)
+                   | (asegd == 31) | (asegd == 63) | (asegd == 10)
+                   | (asegd == 49))
     csfA[idx] = 1
     csfA = imerode(imerode(csfA, se1), se)
 
     # thalmus proper and cuadate are put back because they are not lateral ventricles
-    idx = np.where((asegd == 11) |
-                  (asegd == 50) |
-                  (asegd == 10) |
-                  (asegd == 49))
+    idx = np.where((asegd == 11) | (asegd == 50) | (asegd == 10)
+                   | (asegd == 49))
     csfA[idx] = 0
 
     # REST CSF, IE 3RD AND 4TH VENTRICULE AND EXTRACEREBRAL CSF
-    idx = np.where((asegd == 5) |
-                  (asegd == 14) |
-                  (asegd == 15) |
-                  (asegd == 24) |
-                  (asegd == 44) |
-                  (asegd == 72) |
-                  (asegd == 75) |
-                  (asegd == 76) |
-                  (asegd == 213) |
-                  (asegd == 221))
+    idx = np.where((asegd == 5) | (asegd == 14) | (asegd == 15) | (asegd == 24)
+                   | (asegd == 44) | (asegd == 72) | (asegd == 75)
+                   | (asegd == 76) | (asegd == 213) | (asegd == 221))
     # 43 ??, 4??  213?, 221?
     # more to discuss.
     for i in [5, 14, 15, 24, 44, 72, 75, 76, 213, 221]:
@@ -408,10 +409,12 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
     remaining[idx] = 1
 
     # now remove all the structures from the white matter
-    idx = np.where(
-        (csfA != 0) | (csfB != 0) | (gr_ncl != 0) | (remaining != 0))
+    idx = np.where((csfA != 0) | (csfB != 0) | (gr_ncl != 0)
+                   | (remaining != 0))
     wmmask[idx] = 0
-    iflogger.info("Removing lateral ventricles and eroded grey nuclei and brainstem from white matter mask")
+    iflogger.info(
+        "Removing lateral ventricles and eroded grey nuclei and brainstem from white matter mask"
+    )
 
     # ADD voxels from 'cc_unknown.nii.gz' dataset
     ccun = nb.load(op.join(fs_dir, 'label', 'cc_unknown.nii.gz'))
@@ -421,58 +424,59 @@ def create_wm_mask(subject_id, subjects_dir, fs_dir, parcellation_name):
     wmmask[idx] = 1
 
     # check if we should subtract the cortical rois from this parcellation
-    iflogger.info("Loading %s to subtract cortical ROIs from white matter mask" % ('ROI_%s.nii.gz' % parcellation_name))
+    iflogger.info('Loading ROI_%s.nii.gz to subtract cortical ROIs from white '
+                  'matter mask', parcellation_name)
     roi = nb.load(op.join(op.curdir, 'ROI_%s.nii.gz' % parcellation_name))
     roid = roi.get_data()
     assert roid.shape[0] == wmmask.shape[0]
     pg = nx.read_graphml(pgpath)
-    for brk, brv in pg.nodes_iter(data=True):
+    for brk, brv in pg.nodes(data=True):
         if brv['dn_region'] == 'cortical':
-            iflogger.info("Subtracting region %s with intensity value %s" %
-                          (brv['dn_region'], brv['dn_correspondence_id']))
+            iflogger.info('Subtracting region %s with intensity value %s',
+                          brv['dn_region'], brv['dn_correspondence_id'])
             idx = np.where(roid == int(brv['dn_correspondence_id']))
             wmmask[idx] = 0
 
     # output white matter mask. crop and move it afterwards
     wm_out = op.join(fs_dir, 'mri', 'fsmask_1mm.nii.gz')
-    img = nb.Nifti1Image(wmmask, fsmask.get_affine(), fsmask.get_header())
-    iflogger.info("Save white matter mask: %s" % wm_out)
+    img = nb.Nifti1Image(wmmask, fsmask.affine, fsmask.header)
+    iflogger.info('Save white matter mask: %s', wm_out)
     nb.save(img, wm_out)
 
 
-def crop_and_move_datasets(subject_id, subjects_dir, fs_dir, parcellation_name, out_roi_file,dilation):
+def crop_and_move_datasets(subject_id, subjects_dir, fs_dir, parcellation_name,
+                           out_roi_file, dilation):
     fs_dir = op.join(subjects_dir, subject_id)
     cmp_config = cmp.configuration.PipelineConfiguration()
     cmp_config.parcellation_scheme = "Lausanne2008"
     log = cmp_config.get_logger()
     output_dir = op.abspath(op.curdir)
 
-    iflogger.info("Cropping and moving datasets to %s" % output_dir)
-    ds = [
-        (op.join(fs_dir, 'mri', 'aseg.nii.gz'),
-         op.abspath('aseg.nii.gz')),
-        (op.join(fs_dir, 'mri', 'ribbon.nii.gz'),
-         op.abspath('ribbon.nii.gz')),
-        (op.join(fs_dir, 'mri', 'fsmask_1mm.nii.gz'),
-         op.abspath('fsmask_1mm.nii.gz')),
-        (op.join(fs_dir, 'label', 'cc_unknown.nii.gz'),
-         op.abspath('cc_unknown.nii.gz'))
-    ]
+    iflogger.info('Cropping and moving datasets to %s', output_dir)
+    ds = [(op.join(fs_dir, 'mri', 'aseg.nii.gz'),
+           op.abspath('aseg.nii.gz')), (op.join(fs_dir, 'mri',
+                                                'ribbon.nii.gz'),
+                                        op.abspath('ribbon.nii.gz')),
+          (op.join(fs_dir, 'mri', 'fsmask_1mm.nii.gz'),
+           op.abspath('fsmask_1mm.nii.gz')), (op.join(fs_dir, 'label',
+                                                      'cc_unknown.nii.gz'),
+                                              op.abspath('cc_unknown.nii.gz'))]
 
     ds.append((op.abspath('ROI_%s.nii.gz' % parcellation_name),
-              op.abspath('ROI_HR_th.nii.gz')))
-    if(dilation==True):
-    	ds.append((op.abspath('ROIv_%s.nii.gz' % parcellation_name),
-            op.abspath('ROIv_HR_th.nii.gz')))
+               op.abspath('ROI_HR_th.nii.gz')))
+    if dilation is True:
+        ds.append((op.abspath('ROIv_%s.nii.gz' % parcellation_name),
+                   op.abspath('ROIv_HR_th.nii.gz')))
     orig = op.join(fs_dir, 'mri', 'orig', '001.mgz')
     for d in ds:
-        iflogger.info("Processing %s:" % d[0])
+        iflogger.info('Processing %s:', d[0])
         if not op.exists(d[0]):
             raise Exception('File %s does not exist.' % d[0])
         # reslice to original volume because the roi creation with freesurfer
         # changed to 256x256x256 resolution
-        mri_cmd = 'mri_convert -rl "%s" -rt nearest "%s" -nc "%s"' % (
-            orig, d[0], d[1])
+        mri_cmd = 'mri_convert -rl "%s" -rt nearest "%s" -nc "%s"' % (orig,
+                                                                      d[0],
+                                                                      d[1])
         runCmd(mri_cmd, log)
 
 
@@ -490,12 +494,12 @@ R: the neighbourhood of the specified point in Z
 """
     R = np.ones(shape, dtype=Z.dtype) * \
         fill  # initialize output block to the fill value
-    P = np.array(
-        list(position)).astype(int)  # position coordinates(numpy array)
-    Rs = np.array(
-        list(R.shape)).astype(int)  # output block dimensions (numpy array)
-    Zs = np.array(
-        list(Z.shape)).astype(int)  # original volume dimensions (numpy array)
+    P = np.array(list(position)).astype(
+        int)  # position coordinates(numpy array)
+    Rs = np.array(list(R.shape)).astype(
+        int)  # output block dimensions (numpy array)
+    Zs = np.array(list(Z.shape)).astype(
+        int)  # original volume dimensions (numpy array)
 
     R_start = np.zeros(len(shape)).astype(int)
     R_stop = np.array(list(shape)).astype(int)
@@ -506,40 +510,51 @@ R: the neighbourhood of the specified point in Z
     Z_stop_cor = (np.minimum(Z_stop, Zs)).tolist()  # handle borders
     R_stop = R_stop - (Z_stop - Z_stop_cor)
 
-    R[R_start[0]:R_stop[0], R_start[1]:R_stop[1], R_start[2]:R_stop[2]] = Z[Z_start_cor[0]:Z_stop_cor[0], Z_start_cor[1]:Z_stop_cor[1], Z_start_cor[2]:Z_stop_cor[2]]
+    R[R_start[0]:R_stop[0], R_start[1]:R_stop[1], R_start[2]:R_stop[
+        2]] = Z[Z_start_cor[0]:Z_stop_cor[0], Z_start_cor[1]:Z_stop_cor[1],
+                Z_start_cor[2]:Z_stop_cor[2]]
 
     return R
 
 
 class ParcellateInputSpec(BaseInterfaceInputSpec):
     subject_id = traits.String(mandatory=True, desc='Subject ID')
-    parcellation_name = traits.Enum('scale500', ['scale33', 'scale60', 'scale125', 'scale250', 'scale500'], usedefault=True)
+    parcellation_name = traits.Enum(
+        'scale500', ['scale33', 'scale60', 'scale125', 'scale250', 'scale500'],
+        usedefault=True)
     freesurfer_dir = Directory(exists=True, desc='Freesurfer main directory')
     subjects_dir = Directory(exists=True, desc='Freesurfer subjects directory')
     out_roi_file = File(
         genfile=True, desc='Region of Interest file for connectivity mapping')
-    dilation = traits.Bool(False, usedefault=True,
-                           desc='Dilate cortical parcels? Useful for fMRI connectivity')
+    dilation = traits.Bool(
+        False,
+        usedefault=True,
+        desc='Dilate cortical parcels? Useful for fMRI connectivity')
 
 
 class ParcellateOutputSpec(TraitedSpec):
     roi_file = File(
         exists=True, desc='Region of Interest file for connectivity mapping')
-    roiv_file = File(desc='Region of Interest file for fMRI connectivity mapping')
+    roiv_file = File(
+        desc='Region of Interest file for fMRI connectivity mapping')
     white_matter_mask_file = File(exists=True, desc='White matter mask file')
     cc_unknown_file = File(
         desc='Image file with regions labelled as unknown cortical structures',
-                    exists=True)
-    ribbon_file = File(desc='Image file detailing the cortical ribbon',
-                    exists=True)
+        exists=True)
+    ribbon_file = File(
+        desc='Image file detailing the cortical ribbon', exists=True)
     aseg_file = File(
-        desc='Automated segmentation file converted from Freesurfer "subjects" directory',
-                    exists=True)
+        desc=
+        'Automated segmentation file converted from Freesurfer "subjects" directory',
+        exists=True)
     roi_file_in_structural_space = File(
-        desc='ROI image resliced to the dimensions of the original structural image',
-                    exists=True)
+        desc=
+        'ROI image resliced to the dimensions of the original structural image',
+        exists=True)
     dilated_roi_file_in_structural_space = File(
-        desc='dilated ROI image resliced to the dimensions of the original structural image')
+        desc=
+        'dilated ROI image resliced to the dimensions of the original structural image'
+    )
 
 
 class Parcellate(BaseInterface):
@@ -569,14 +584,24 @@ class Parcellate(BaseInterface):
         if self.inputs.subjects_dir:
             os.environ.update({'SUBJECTS_DIR': self.inputs.subjects_dir})
 
-        if not os.path.exists(op.join(self.inputs.subjects_dir, self.inputs.subject_id)):
+        if not os.path.exists(
+                op.join(self.inputs.subjects_dir, self.inputs.subject_id)):
             raise Exception
         iflogger.info("ROI_HR_th.nii.gz / fsmask_1mm.nii.gz CREATION")
         iflogger.info("=============================================")
-        create_annot_label(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name)
-        create_roi(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name, self.inputs.dilation)
-        create_wm_mask(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name)
-        crop_and_move_datasets(self.inputs.subject_id, self.inputs.subjects_dir, self.inputs.freesurfer_dir, self.inputs.parcellation_name, self.inputs.out_roi_file,self.inputs.dilation)
+        create_annot_label(self.inputs.subject_id, self.inputs.subjects_dir,
+                           self.inputs.freesurfer_dir,
+                           self.inputs.parcellation_name)
+        create_roi(self.inputs.subject_id, self.inputs.subjects_dir,
+                   self.inputs.freesurfer_dir, self.inputs.parcellation_name,
+                   self.inputs.dilation)
+        create_wm_mask(self.inputs.subject_id, self.inputs.subjects_dir,
+                       self.inputs.freesurfer_dir,
+                       self.inputs.parcellation_name)
+        crop_and_move_datasets(
+            self.inputs.subject_id, self.inputs.subjects_dir,
+            self.inputs.freesurfer_dir, self.inputs.parcellation_name,
+            self.inputs.out_roi_file, self.inputs.dilation)
         return runtime
 
     def _list_outputs(self):
@@ -586,18 +611,18 @@ class Parcellate(BaseInterface):
         else:
             outputs['roi_file'] = op.abspath(
                 self._gen_outfilename('nii.gz', 'ROI'))
-        if(self.inputs.dilation==True):
-            outputs['roiv_file'] = op.abspath(self._gen_outfilename(
-            'nii.gz', 'ROIv'))
+        if self.inputs.dilation is True:
+            outputs['roiv_file'] = op.abspath(
+                self._gen_outfilename('nii.gz', 'ROIv'))
         outputs['white_matter_mask_file'] = op.abspath('fsmask_1mm.nii.gz')
         outputs['cc_unknown_file'] = op.abspath('cc_unknown.nii.gz')
         outputs['ribbon_file'] = op.abspath('ribbon.nii.gz')
         outputs['aseg_file'] = op.abspath('aseg.nii.gz')
         outputs['roi_file_in_structural_space'] = op.abspath(
             'ROI_HR_th.nii.gz')
-        if(self.inputs.dilation==True):
+        if self.inputs.dilation is True:
             outputs['dilated_roi_file_in_structural_space'] = op.abspath(
-            'ROIv_HR_th.nii.gz')
+                'ROIv_HR_th.nii.gz')
         return outputs
 
     def _gen_outfilename(self, ext, prefix='ROI'):
